@@ -1,11 +1,11 @@
 use strict;
 use warnings;
-package Dist::Zilla::Plugin::Git::Contributors; # git description: v0.028-2-g5a92088
+package Dist::Zilla::Plugin::Git::Contributors; # git description: v0.030-7-gc91f404
 # vim: set ts=8 sts=4 sw=4 tw=115 et :
 # ABSTRACT: Add contributor names from git to your distribution
 # KEYWORDS: plugin distribution metadata git contributors authors commits
 
-our $VERSION = '0.029';
+our $VERSION = '0.031';
 
 use Moose;
 with 'Dist::Zilla::Role::MetaProvider',
@@ -71,7 +71,7 @@ around dump_config => sub
                      ($dist_root->subsumes($p) ? $p->relative($dist_root) : $p)->stringify
                    } $self->paths ],
         $self->remove ? ( remove => '...' ) : (),
-        'git --version' => $self->_git('version'),
+        git_version => $self->_git('version'),
         blessed($self) ne __PACKAGE__ ? ( version => $VERSION ) : (),
     };
 
@@ -267,7 +267,7 @@ Dist::Zilla::Plugin::Git::Contributors - Add contributor names from git to your
 
 =head1 VERSION
 
-version 0.029
+version 0.031
 
 =head1 SYNOPSIS
 
@@ -415,7 +415,7 @@ Karen Etheridge <ether@cpan.org>
 
 =head1 CONTRIBUTORS
 
-=for stopwords Kent Fredric Klaus Eichner Matthew Horsfall Mohammad S Anwar
+=for stopwords Kent Fredric Ioan Rogers Klaus Eichner Matthew Horsfall Mohammad S Anwar
 
 =over 4
 
@@ -425,6 +425,10 @@ Kent Fredric <kentnl@cpan.org>
 
 =item *
 
+Ioan Rogers <ioan@dirtysoft.ca>
+
+=item *
+
 Klaus Eichner <klaus03@gmail.com>
 
 =item *
